==> llexec-1.1.4.tgz: package/lib/index.js <==
#!/usr/bin/env node
"use strict";
var executor_1 = require('./executor');
var cmdname_color_1 = require('./canned-wrappers/cmdname-color');
var firstarg_color_1 = require('./canned-wrappers/firstarg-color');
var timestamp_color_1 = require('./canned-wrappers/timestamp-color');
var lineWrappers = {
    'cmdname': cmdname_color_1.lineWrapper,
    'firstarg': firstarg_color_1.lineWrapper,
    'timestamp': timestamp_color_1.lineWrapper
};
var argv = require('yargs').argv;
if (argv._.length < 1) {
    console.log("\nllexec - run arbitrary commands in parallel\n\nllexec is designed to take a list of commands, run them in parallel, and perform\noutput buffering on the results so the output is human-readable.\n\nusage:\n  llexec [-w line-wrapper] cmd [, cmd, [...]]\n\n  possible line-wrappers:\n    cmdname:    prefixes each line with the name of the command\n    firstarg:   prefixes each line with the first argument (useful for build tools)\n    timestamp:  prefixes each line with a timestamp\n\nexamples:\n\n  llexec -w cmdname 'tsc -p src/' 'scss -w scss/'\n  llexec -w firstarg 'make module1' 'make module2'\n");
    process.exit(1);
}
var subcommands = argv._.map(function (commandString) {
    commandString = commandString.replace(/:::\s*/, '');
    return { command: commandString };
});
var instance = new executor_1.Executor(lineWrappers[argv.w]);
instance.run(subcommands).then(function () {
    process.exit(0);
}).catch(function (failedJobs) {
    console.error();
    failedJobs.forEach(function (j) { return console.error("[llexec: job failed]: " + j.command); });
    process.exit(1);
});

==> llexec-1.2.0.tgz: package/lib/index.js <==
#!/usr/bin/env node
"use strict";
var executor_1 = require('./executor');
var cmdname_color_1 = require('./canned-wrappers/cmdname-color');
var firstarg_color_1 = require('./canned-wrappers/firstarg-color');
var timestamp_color_1 = require('./canned-wrappers/timestamp-color');
var pid_color_1 = require('./canned-wrappers/pid-color');
var lineWrappers = {
    'cmdname': cmdname_color_1.lineWrapper,
    'firstarg': firstarg_color_1.lineWrapper,
    'timestamp': timestamp_color_1.lineWrapper,
    'pid': pid_color_1.lineWrapper
};
var argv = require('yargs').argv;
if (argv._.length < 1) {
    console.log("\nllexec - run arbitrary commands in parallel\n\nllexec is designed to take a list of commands, run them in parallel, and perform\noutput buffering on the results so the output is human-readable.\n\nusage:\n  llexec [-w line-wrapper] cmd [, cmd, [...]]\n\n  possible line-wrappers:\n    cmdname:    prefixes each line with the name of the command\n    firstarg:   prefixes each line with the first argument (useful for build tools)\n    timestamp:  prefixes each line with a timestamp\n\nexamples:\n\n  llexec -w cmdname 'tsc -p src/' 'scss -w scss/'\n  llexec -w firstarg 'make module1' 'make module2'\n");
    process.exit(1);
}
var subcommands = argv._.map(function (commandString) {
    commandString = commandString.replace(/:::\s*/, '');
    return { command: commandString };
});
var instance = new executor_1.Executor(lineWrappers[argv.w]);
instance.run(subcommands).then(function () {
    process.exit(0);
}).catch(function (failedJobs) {
    failedJobs.forEach(function (j) { return console.error("[llexec: (" + process.pid + ") job failed]: " + j.command); });
    instance.killall();
    process.exit(1);
});
